==> butaca-server_0.1-1.tar.gz: butaca-server-0.1/src/btc-minfo-provider-service.h <==
/*
 * btc-minfo-provider-service.h
 *
 * This file is part of butaca
 * Copyright (C) 2010 Simón Pena <spenap@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 */

#ifndef _BTC_MINFO_PROVIDER_SERVICE
#define _BTC_MINFO_PROVIDER_SERVICE

#include <glib-object.h>

G_BEGIN_DECLS

#define BTC_TYPE_MINFO_PROVIDER_SERVICE btc_minfo_provider_service_get_type()
#define BTC_MINFO_PROVIDER_SERVICE(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), BTC_TYPE_MINFO_PROVIDER_SERVICE, BtcMInfoProviderService))
#define BTC_MINFO_PROVIDER_SERVICE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), BTC_TYPE_MINFO_PROVIDER_SERVICE, BtcMInfoProviderServiceClass))
#define BTC_IS_MINFO_PROVIDER_SERVICE(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BTC_TYPE_MINFO_PROVIDER_SERVICE))
#define BTC_IS_MINFO_PROVIDER_SERVICE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), BTC_TYPE_MINFO_PROVIDER_SERVICE))
#define BTC_MINFO_PROVIDER_SERVICE_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), BTC_TYPE_MINFO_PROVIDER_SERVICE, BtcMInfoProviderServiceClass))

typedef struct _BtcMInfoProviderServicePrivate BtcMInfoProviderServicePrivate;

typedef struct {
        GObject parent;

        /* <private> */
        BtcMInfoProviderServicePrivate *priv;
} BtcMInfoProviderService;

typedef struct {
        GObjectClass parent_class;
} BtcMInfoProviderServiceClass;

GType btc_minfo_provider_service_get_type (void);
BtcMInfoProviderService* btc_minfo_provider_service_new (DBusGConnection *connection);

G_END_DECLS

#endif /* _BTC_MINFO_PROVIDER_SERVICE */

==> butaca-server_0.1-2.tar.gz: butaca-server-0.1/src/btc-minfo-provider-service.h <==
/*
 * btc-minfo-provider-service.h
 *
 * This file is part of butaca
 * Copyright (C) 2010 Simón Pena <spenap@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 */

#ifndef _BTC_MINFO_PROVIDER_SERVICE
#define _BTC_MINFO_PROVIDER_SERVICE

#include <glib-object.h>

G_BEGIN_DECLS

#define BTC_TYPE_MINFO_PROVIDER_SERVICE btc_minfo_provider_service_get_type()
#define BTC_MINFO_PROVIDER_SERVICE(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), BTC_TYPE_MINFO_PROVIDER_SERVICE, BtcMInfoProviderService))
#define BTC_MINFO_PROVIDER_SERVICE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), BTC_TYPE_MINFO_PROVIDER_SERVICE, BtcMInfoProviderServiceClass))
#define BTC_IS_MINFO_PROVIDER_SERVICE(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BTC_TYPE_MINFO_PROVIDER_SERVICE))
#define BTC_IS_MINFO_PROVIDER_SERVICE_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), BTC_TYPE_MINFO_PROVIDER_SERVICE))
#define BTC_MINFO_PROVIDER_SERVICE_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), BTC_TYPE_MINFO_PROVIDER_SERVICE, BtcMInfoProviderServiceClass))

typedef struct _BtcMInfoProviderServicePrivate BtcMInfoProviderServicePrivate;

typedef struct {
        GObject parent;

        /* <private> */
        BtcMInfoProviderServicePrivate *priv;
} BtcMInfoProviderService;

typedef struct {
        GObjectClass parent_class;
} BtcMInfoProviderServiceClass;

GType btc_minfo_provider_service_get_type (void);
BtcMInfoProviderService* btc_minfo_provider_service_new (DBusGConnection *connection,
                                                         GMainLoop *loop);

G_END_DECLS

#endif /* _BTC_MINFO_PROVIDER_SERVICE */
